(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["exports"], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports);
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports);
    global.index = mod.exports;
  }
})(this, function (_exports) {
  "use strict";

  Object.defineProperty(_exports, "__esModule", {
    value: true
  });
  _exports.closest = closest;
  _exports.query = query;
  _exports.querySelectorAll = querySelectorAll;
  _exports.namedItem = namedItem;
  _exports.getAttribute = getAttribute;

  /*  strict */
  function closest(element, selectors, type) {
    var klass = type || HTMLElement;
    var el = element.closest(selectors);

    if (el instanceof klass) {
      return el;
    }

    throw new Error("Element not found: <".concat(klass.name, "> ").concat(selectors));
  }

  function query(context, selectors, type) {
    var klass = type || HTMLElement;
    var el = context.querySelector(selectors);

    if (el instanceof klass) {
      return el;
    }

    throw new Error("Element not found: <".concat(klass.name, "> ").concat(selectors));
  }

  function querySelectorAll(context, selectors, type) {
    var klass = type || HTMLElement;
    var els = [];
    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = context.querySelectorAll(selectors)[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        var el = _step.value;

        if (el instanceof klass) {
          els.push(el);
        }
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator.return != null) {
          _iterator.return();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }

    return els;
  }

  function namedItem(form, itemName, type) {
    var klass = type || HTMLInputElement;
    var el = form.elements.namedItem(itemName);

    if (el instanceof klass) {
      return el;
    }

    throw new Error("Element not found by name: <".concat(klass.name, "> ").concat(itemName));
  }

  function getAttribute(element, attributeName) {
    var attribute = element.getAttribute(attributeName);

    if (attribute != null) {
      return attribute;
    }

    throw new Error("Attribute not found on element: ".concat(attributeName));
  }
});
